# Migrating from v1 to v2

Carbon v2 has changed the test runner from Karma to [Jest](https://facebook.github.io/jest/).

## Carbon Factory Test Setup Changes

### Basic Setup Changes

You need to create a `.babelrc` file in the root of your application (alongside your `gulpfile.js`), this should contain the following:

```
{
  "extends": "./node_modules/carbon-factory/.babelrc"
}
```

For the simplest of setups there should be no additional changes required when migration from v1 and v2. `gulp test` and `gulp test --build` should mostly work the same as before and will automatically include coverage reports. However there are some important steps to note:

* It is recommended that you [setup the JestCLI](https://github.com/Sage/carbon-factory/blob/master/docs/setting-up-jest-cli.md).
* For builds using custom configuration options see [Advanced Configuration](https://github.com/Sage/carbon-factory/blob/master/docs/running-tests.md#advanced-configuration).
* For build using spec helpers see the [Spec Helpers](#spec-helpers) upgrade guide.
* Some specs may need to be rewritten to pass successfully, see the [Spec Updates](#spec-updates) upgrade guide.


### Gulpfile

If you have created a custom `jest.conf.json` file, you will want to use this when running the build through gulp. Update your `gulpfile.js` to pass this config file to the test runner:

```js
gulp.task('test', SpecTask({
  jestConfig: require('./jest.conf.json')
}));
```

### Babel Transforms

We previously supported a config called `babelTransforms`. You can now configure this manually in your `jest.conf.json` file.

For example if you were previously setting a module called `my-app` to the `babelTransforms` config, you need to add the following config:

```
"transformIgnorePatterns": [ "node_modules\/(?!my-app)" ],
```

### Spec Helpers

v1 of Carbon Factory allowed you to define spec helpers that would run before any of the tests. In Jest these helpers need to be included using the `setupFiles` option in your Jest config. To add a basic spec helper file add the following to your `jest.conf.json` file.

```js
"setupFiles": [
  "./src/__spec_helper__/index.js"
],
```

You can provide an array of multiple files here, but it is probably easier to maintain a single file which imports all of the other spec helpers.

### Spec Updates

Jest is forked from Jasmine and therefore follows a lot of the same syntax, style and conventions. This means that migrating from jasmine should be easy. However as a fork, Jest, has removed some of Jasmines features in favor of their own implementations. We have compiled a small list of common changes you may be required to make to convert your tests from Jasmine to Jest.

Please find detail on the [Help with Jest](https://github.com/Sage/carbon-factory/blob/master/docs/help-with-jest.md) document.
